
loglevel
========


.. image:: https://img.shields.io/pypi/v/package_name.svg
   :target: https://pypi.python.org/pypi/package_name
   :alt: Latest PyPI version


Usage
=====

.. code-block:: python

   import loglevel
   loglevel.set_loglevel('loglevel.yml')

yaml data
^^^^^^^^^

.. code-block:: yaml

   keyring: WARNING
   keyring.backend: WARNING
   websocket: WARNING
   requests: WARNING
   selenium: WARNING
   seleniumrequests: WARNING
   urllib3: WARNING
   nose: WARNING

Installation
============

Requirements
============

Compatibility
=============

Licence
=======

Authors
=======

package_name was written by `fx-kirin <fx.kirin@gmail.com>`_.
